﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#include <aws/emr-serverless/model/ListJobRunAttemptsResult.h>
#include <aws/core/utils/json/JsonSerializer.h>
#include <aws/core/AmazonWebServiceResult.h>
#include <aws/core/utils/StringUtils.h>
#include <aws/core/utils/UnreferencedParam.h>
#include <aws/core/utils/memory/stl/AWSStringStream.h>

#include <utility>

using namespace Aws::EMRServerless::Model;
using namespace Aws::Utils::Json;
using namespace Aws::Utils;
using namespace Aws;

ListJobRunAttemptsResult::ListJobRunAttemptsResult()
{
}

ListJobRunAttemptsResult::ListJobRunAttemptsResult(const Aws::AmazonWebServiceResult<JsonValue>& result)
{
  *this = result;
}

ListJobRunAttemptsResult& ListJobRunAttemptsResult::operator =(const Aws::AmazonWebServiceResult<JsonValue>& result)
{
  JsonView jsonValue = result.GetPayload().View();
  if(jsonValue.ValueExists("jobRunAttempts"))
  {
    Aws::Utils::Array<JsonView> jobRunAttemptsJsonList = jsonValue.GetArray("jobRunAttempts");
    for(unsigned jobRunAttemptsIndex = 0; jobRunAttemptsIndex < jobRunAttemptsJsonList.GetLength(); ++jobRunAttemptsIndex)
    {
      m_jobRunAttempts.push_back(jobRunAttemptsJsonList[jobRunAttemptsIndex].AsObject());
    }
  }

  if(jsonValue.ValueExists("nextToken"))
  {
    m_nextToken = jsonValue.GetString("nextToken");

  }


  const auto& headers = result.GetHeaderValueCollection();
  const auto& requestIdIter = headers.find("x-amzn-requestid");
  if(requestIdIter != headers.end())
  {
    m_requestId = requestIdIter->second;
  }


  return *this;
}
